About
------

`Naked <http://naked-py.com>`_ is a new Python command line application
framework that is in development.  The current release is a stable, testing
release.

Updates
--------

Changes, updates, and brief tutorials are available on the `developer log
<http://nakedpy.wordpress.com/>`_.

QuickStart Guide
------------------

The quickstart guide is available at
`http://naked.readthedocs.io/quickstart.html
<http://naked.readthedocs.io/quickstart.html>`_. It demonstrates how the
available tools can be incorporated into your development workflow, spanning
the entire period from an empty project directory to your first PyPI version
release.

Documentation
--------------

Documentation is in development at `http://naked.readthedocs.io/
<http://naked.readthedocs.io/>`_

Issue Reporting
----------------

Issue reporting is available on the `GitHub repository
<http://github.com/chrissimpkins/naked/issues>`_

Contribute
-----------

I would greatly appreciate feedback from anyone who is testing the framework.
Feel free to contact me on Twitter (`@csimpkins <https://twitter.com/csimpkins`_) if you have questions,
comments, or problems.  Please use the issue reporting link above for bug
reports.

Example Application
-------------------

`Status <https://pypi.python.org/pypi/status>`_ was built from the ground up
with the Naked Framework.  If you'd like to check out the source, it is
available on `GitHub
<https://github.com/chrissimpkins/status/tree/master/lib/status>`_
